summaryrefslogtreecommitdiffstats
path: root/usr.bin/make
diff options
context:
space:
mode:
authorobrien <obrien@FreeBSD.org>2002-04-13 12:18:00 +0000
committerobrien <obrien@FreeBSD.org>2002-04-13 12:18:00 +0000
commit296a363e574bbd71a874bac9d2511726b60391a4 (patch)
treef3131d92f7b4297b0ccdf24511ea5c8738148ef5 /usr.bin/make
parent40ecff682a53fcbf04df8f4c3871d9a6d7547855 (diff)
downloadFreeBSD-src-296a363e574bbd71a874bac9d2511726b60391a4.zip
FreeBSD-src-296a363e574bbd71a874bac9d2511726b60391a4.tar.gz
Prefer BSDmakefile over makefile and Makefile.
Submitted by: jmallett Obtained from: OpenBSD
Diffstat (limited to 'usr.bin/make')
-rw-r--r--usr.bin/make/job.c8
-rw-r--r--usr.bin/make/job.h2
-rw-r--r--usr.bin/make/main.c3
-rw-r--r--usr.bin/make/make.11
-rw-r--r--usr.bin/make/make.c2
5 files changed, 9 insertions, 7 deletions
diff --git a/usr.bin/make/job.h b/usr.bin/make/job.h
index d59bc16..98d7994 100644
--- a/usr.bin/make/job.h
+++ b/usr.bin/make/job.h
@@ -229,7 +229,7 @@ void Job_Init(int, int);
Boolean Job_Full(void);
Boolean Job_Empty(void);
ReturnStatus Job_ParseShell(char *);
-int Job_End(void);
+int Job_Finish(void);
void Job_Wait(void);
void Job_AbortAll(void);
void JobFlagForMigration(int);
diff --git a/usr.bin/make/main.c b/usr.bin/make/main.c
index f3c2ca7..f99c0ba 100644
--- a/usr.bin/make/main.c
+++ b/usr.bin/make/main.c
@@ -748,7 +748,8 @@ main(argc, argv)
ln = Lst_Find(makefiles, (void *)NULL, ReadMakefile);
if (ln != NULL)
Fatal("make: cannot open %s.", (char *)Lst_Datum(ln));
- } else if (!ReadMakefile("makefile", NULL))
+ } else if (!ReadMakefile("BSDmakefile", NULL))
+ if (!ReadMakefile("makefile", NULL))
(void)ReadMakefile("Makefile", NULL);
(void)ReadMakefile(".depend", NULL);
diff --git a/usr.bin/make/make.1 b/usr.bin/make/make.1
index f764be9..88bcf9a 100644
--- a/usr.bin/make/make.1
+++ b/usr.bin/make/make.1
@@ -60,6 +60,7 @@ Its input is a list of specifications
describing dependency relationships between the generation of
files and programs.
The first of
+.Ql Pa BSDmakefile ,
.Ql Pa makefile
and
.Ql Pa Makefile
diff --git a/usr.bin/make/make.c b/usr.bin/make/make.c
index d02a435..2db6635 100644
--- a/usr.bin/make/make.c
+++ b/usr.bin/make/make.c
@@ -895,7 +895,7 @@ Make_Run (targs)
(void)MakeStartJobs();
}
- errors = Job_End();
+ errors = Job_Finish();
/*
* Print the final status of each target. E.g. if it wasn't made
OpenPOWER on IntegriCloud
diff --git a/usr.bin/make/job.c b/usr.bin/make/job.c
index ed1ee08..bf98c91 100644
--- a/usr.bin/make/job.c
+++ b/usr.bin/make/job.c
@@ -83,7 +83,7 @@ __FBSDID("$FreeBSD$");
* the line as a shell specification. Returns
* FAILURE if the spec was incorrect.
*
* Job_End Perform any final processing which needs doing.
* This includes the execution of any commands
* which have been/were attached to the .END
* target. It should only be called when the
@@ -501,7 +501,7 @@ JobCmpRmtID(job, rmtID)
* job to be commands to be executed once the entire graph has been
* made and return non-zero to signal that the end of the commands
* was reached. These commands are later attached to the postCommands
* node and executed by Job_End when all things are done.
* This function is called from JobStart via Lst_ForEach.
*
* Results:
@@ -2915,7 +2915,7 @@ JobInterrupt(runINTERRUPT, signo)
/*
*-----------------------------------------------------------------------
- * Job_End --
+ * Job_Finish --
* Do final processing such as the running of the commands
* attached to the .END target.
*
@@ -2924,7 +2924,7 @@ JobInterrupt(runINTERRUPT, signo)
*-----------------------------------------------------------------------
*/
int
-Job_End()
+Job_Finish()
{
if (postCommands != NULL && !Lst_IsEmpty(postCommands->commands)) {
if (errors) {
@@ -83,7 +83,7 @@ __FBSDID("$FreeBSD$");
* FAILURE if the spec was incorrect.
*
- * Job_End Perform any final processing which needs doing.
+ * Job_Finish Perform any final processing which needs doing.
* This includes the execution of any commands
* which have been/were attached to the .END
@@ -501,7 +501,7 @@ JobCmpRmtID(job, rmtID)
* made and return non-zero to signal that the end of the commands
* was reached. These commands are later attached to the postCommands
- * node and executed by Job_End when all things are done.
+ * node and executed by Job_Finish when all things are done.
* This function is called from JobStart via Lst_ForEach.
*